@@ -42,6 +42,8 @@
 #include <QFile>
 #include <QUuid>
 #include <QInputDialog>
+
+#include <kwidgetsaddons_version.h>
 #include <KLocalizedString>
 #include <KLineEdit>
 #include <KMessageBox>
@@ -151,7 +153,7 @@ GameAutomaton::GameAutomaton() :
     KGame(),
     m_aicannotrunhack(true),
     m_state(INIT),
-    m_game(0),
+    m_game(nullptr),
     m_networkPlayersNumber(0),
     m_currentPlayer(""),
     m_currentPlayerPlayed(false),
@@ -234,13 +236,13 @@ Player* GameAutomaton::getAnyLocalPlayer()
       return (Player*)(*it);
     }
   }
-  return 0;
+  return nullptr;
 }
 
 GameAutomaton::GameState GameAutomaton::run()
 {
 //   qCDebug(KSIRK_LOG) << "(KGame running=" <<  (gameStatus()==KGame::Run) << ")";
-  if (m_game == 0 || gameStatus() == KGame::Pause)
+  if (m_game == nullptr || gameStatus() == KGame::Pause)
   {
     QTimer::singleShot(200, this, &GameAutomaton::run);
     return m_state;
@@ -321,7 +323,7 @@ GameAutomaton::GameState GameAutomaton::run()
   switch (m_state)
   {
   case INIT:
-    if (currentPlayer() != 0 && isAdmin())
+    if (currentPlayer() != nullptr && isAdmin())
     {
       if  ( (event == "actionLButtonDown") && (m_game->playerPutsInitialArmy(point)) )
       {
@@ -672,7 +674,7 @@ GameAutomaton::GameState GameAutomaton::run()
       {
       if (allLocalPlayersComputer())
         {
-          m_game->getRightDialog()->updateRecycleDetails(NULL,true,0);
+          m_game->getRightDialog()->updateRecycleDetails(nullptr,true,0);
           m_game->displayRecyclingButtons();
         }
       }
@@ -693,7 +695,7 @@ GameAutomaton::GameState GameAutomaton::run()
       stream << quint32(2);
       sendMessage(buffer,ActionDefense);
     }
-    else if ( m_game->secondCountry() != 0
+    else if ( m_game->secondCountry() != nullptr
           && !m_game->secondCountry()->owner()->isVirtual()
           && isDefenseAuto()
           && (m_game->secondCountry()->owner()->getNbDefense() == 0) )
@@ -1049,7 +1051,7 @@ void GameAutomaton::createIO(KPlayer *player,KGameIO::IOMode io)
   }
   else if (io&AIPLAYERIO)
   {
-    if (dynamic_cast<AIPlayer*>(player) != 0)
+    if (dynamic_cast<AIPlayer*>(player) != nullptr)
     {
       /*AIPlayerIO* input =*/ new AIPlayerIO(dynamic_cast<AIPlayer*>(player));
     }
@@ -1138,8 +1140,8 @@ void GameAutomaton::setGoalFor(Player* player)
   qCDebug(KSIRK_LOG) << "Goal for " << player->name() << " is of type " << goal->type();
   if (goal->type() == Goal::GoalPlayer)
   {
-    Player* target = 0;
-    while (target==0 || target->id() == player->id())
+    Player* target = nullptr;
+    while (target==nullptr || target->id() == player->id())
     {
       unsigned int max = playerList()->count();
       unsigned int playerNum = Dice::roll(max);
@@ -1149,7 +1151,7 @@ void GameAutomaton::setGoalFor(Player* player)
       for (; j < playerNum; j++,itp++) {}
       target = dynamic_cast< Player* >(*itp);
     }
-    if (target != 0)
+    if (target != nullptr)
     {
 //       qCDebug(KSIRK_LOG) << "Target choice for " << player->name() << ": " << target->name();
       goal->players().push_back(target->name());
@@ -1184,7 +1186,7 @@ bool GameAutomaton::joinNetworkGame()
 {
   qCDebug(KSIRK_LOG);
    if (stateName() == "INIT"
-     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KStandardGuiItem::yes()) == KMessageBox::Continue))
+     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
    {
       m_game->joinNetworkGame();
    }
@@ -1194,7 +1196,7 @@ bool GameAutomaton::joinNetworkGame()
 bool GameAutomaton::connectToServ()
 {
   qCDebug(KSIRK_LOG);
-  if (messageServer() != 0)
+  if (messageServer() != nullptr)
   {
     QObject::disconnect(messageServer(),&KMessageServer::connectionLost,
                         this,&GameAutomaton::slotConnectionToClientBroken);
@@ -1212,14 +1214,14 @@ bool GameAutomaton::connectToServ()
 
 bool GameAutomaton::joinJabberGame(const QString& nick)
 {
-  if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KStandardGuiItem::yes()) == KMessageBox::Continue))
+  if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KGuiItem(i18nc("@action:button", "Join New Game"))) == KMessageBox::Continue))
   {
     // stop game
     setGameStatus(KGame::End);
     state(INIT);
     savedState(INVALID);
     
-    if (messageServer() != 0)
+    if (messageServer() != nullptr)
     {
       QObject::disconnect(messageServer(),&KMessageServer::connectionLost,
                            this,&GameAutomaton::slotConnectionToClientBroken);
@@ -1254,7 +1256,7 @@ KPlayer * GameAutomaton::createPlayer(int rtti,
   qCDebug(KSIRK_LOG) << "(" << rtti << ", " << isVirtual << ")";
   if (rtti == 1)
   {
-    Player* p = new Player(this, "", 0, 0);
+    Player* p = new Player(this, "", 0, nullptr);
     p->setVirtual(isVirtual);
     if (!isVirtual)
     {
@@ -1265,7 +1267,7 @@ KPlayer * GameAutomaton::createPlayer(int rtti,
   }
   else if (rtti == 2)
   {
-    AIPlayer* aip = new AIColsonPlayer("", 0, 0,  *playerList(), m_game->theWorld(),
+    AIPlayer* aip = new AIColsonPlayer("", 0, nullptr,  *playerList(), m_game->theWorld(),
                                    this);
     aip->stop();
     aip->setVirtual(isVirtual);
@@ -1279,7 +1281,7 @@ KPlayer * GameAutomaton::createPlayer(int rtti,
   else 
   {
     qCCritical(KSIRK_LOG) << "No rtti given... creating a Player";
-    Player* p = new Player(this, "", 0, 0);
+    Player* p = new Player(this, "", 0, nullptr);
     p->setVirtual(isVirtual);
     if (!isVirtual)
     {
@@ -1306,7 +1308,7 @@ Player* GameAutomaton::playerNamed(const QString& playerName)
   }
   qCCritical(KSIRK_LOG) << "GameAutomaton::playerNamed: there is no player named " 
       << playerName ;
-  return 0;
+  return nullptr;
 }
 
 Player* GameAutomaton::currentPlayer() 
@@ -1315,7 +1317,7 @@ Player* GameAutomaton::currentPlayer()
   {
     return playerNamed(m_currentPlayer);
   }
-  else return 0;
+  else return nullptr;
 }
 
 void GameAutomaton::currentPlayer(Player* player) 
@@ -1509,7 +1511,7 @@ void GameAutomaton::changePlayerName(Player* player)
       if (nomEntre.isEmpty())
       {
         mes = i18n("Error - Player %1, you have to choose a name.", 1);
-        KMessageBox::sorry(m_game, mes, i18n("Error"));
+        KMessageBox::error(m_game, mes);
         nomEntre = i18nc("@info Forged player name", "Player%1", 1);
       }
       else 
@@ -1602,7 +1604,7 @@ void GameAutomaton::slotPropertyChanged(KGamePropertyBase *prop,KGame *)
   {
     qCDebug(KSIRK_LOG) << "skin changed to: " << m_skin ;
     m_game->newSkin();
-    if (m_game->theWorld()!=0)
+    if (m_game->theWorld()!=nullptr)
     {
       m_game->theWorld()->reset();
     }
@@ -1652,17 +1654,29 @@ void GameAutomaton::slotConnectionToServerBroken()
 //   m_game->haltTimer();
   if (m_state != GAME_OVER)
   {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int answer = KMessageBox::questionTwoActionsCancel(m_game,
+#else
     int answer = KMessageBox::questionYesNoCancel(m_game,
+#endif
                                                   i18n("KsirK - Lost connection to server!\nWhat do you want to do?"),
                                                   i18n("Starting a new game or exit."),
                                                   KGuiItem(i18n("New Game")),
                                                   KGuiItem(i18n("Exit")),
                                                   KGuiItem(i18n("Do nothing")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::PrimaryAction)
+#else
     if (answer == KMessageBox::Yes)
+#endif
     {
       m_game->showMainMenu();
     }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    else if (answer == KMessageBox::SecondaryAction)
+#else
     else if (answer == KMessageBox::No)
+#endif
     {
       exit(0);
     }
@@ -1681,12 +1695,27 @@ void GameAutomaton::slotConnectionToClientBroken(KMessageIO *)
     KMessageBox::information(m_game, 
                             i18n("Lost connection to a client.\nFor the moment, you can only save the game and start a new one or quit.\nThis will be improved in a future version."), 
                             i18n("KsirK - Lost connection to client!"));
-    switch ( KMessageBox::warningYesNo( m_game, i18n("Do want to save your game?")) ) 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    switch ( KMessageBox::warningTwoActions( m_game,
+#else
+    switch ( KMessageBox::warningYesNo( m_game,
+#endif
+                                        i18n("Do want to save your game?"),
+                                        QString(),
+                                        KStandardGuiItem::save(), KStandardGuiItem::discard()) )
     {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::PrimaryAction :
+#else
     case KMessageBox::Yes :
+#endif
       m_game->slotSaveGame();
       break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::SecondaryAction :;
+#else
     case KMessageBox::No :;
+#endif
     default: ;
     }
     if (!m_game->actionNewGame(GameAutomaton::None))
@@ -1921,7 +1950,7 @@ void GameAutomaton::displayGoals()
   PlayersArray::iterator it_end = playerList()->end();
   for (; it != it_end; it++)
   {
-    if ( (dynamic_cast<Player*>(*it) != 0)
+    if ( (dynamic_cast<Player*>(*it) != nullptr)
         && ( ! dynamic_cast<Player*>(*it)-> isVirtual() )
         && ( ! dynamic_cast<Player*>(*it)-> isAI() ) )
     {
@@ -1959,7 +1988,7 @@ void GameAutomaton::setAttackAuto(bool activated)
 void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32 receiver, quint32 sender)
 {
   qCDebug(KSIRK_LOG) << "msg " << msgid << " ; rec="<<receiver << " snd=" << sender ;
-  if (m_game == 0)
+  if (m_game == nullptr)
   {
     exit(0);
   }
@@ -2003,7 +2032,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   quint32 elemType;
   quint32 nb;
   
-  if (currentPlayer() != 0 && currentPlayer()->getFlag() != 0)
+  if (currentPlayer() != nullptr && currentPlayer()->getFlag() != nullptr)
   {
     pm = currentPlayer()->getFlag()->image(0);
   }
@@ -2056,7 +2085,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case PlayerAvailArmies:
     if (sender == gameId()) break;
     stream >> playerName >> nbArmies;
-    if (playerNamed(playerName) != 0)
+    if (playerNamed(playerName) != nullptr)
       playerNamed(playerName)->setNbAvailArmies((unsigned int)nbArmies, false);
     break;
 /*  case KGameWinAvailArmies:
@@ -2092,7 +2121,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     m_game->changeItem(messageParts,statusBarId, logStatus);
     break;
   case DisplayRecyclingButtons:
-    m_game->getRightDialog()->updateRecycleDetails(0,true,0);
+    m_game->getRightDialog()->updateRecycleDetails(nullptr,true,0);
     m_game->displayRecyclingButtons();
     break;
   case ClearHighlighting:
@@ -2471,7 +2500,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     qCDebug(KSIRK_LOG) << "  player id: " << playerId ;
     stream >> goal;
     player = dynamic_cast<Player*>(findPlayer(playerId));
-    if (player != 0)
+    if (player != nullptr)
     {
       player->goal(goal);
     }
@@ -2598,8 +2627,8 @@ void GameAutomaton::setDefenseAuto(bool activated)
   }
   else
   {
-    m_defenseAuto.firstCountry = 0;
-    m_defenseAuto.secondCountry= 0;
+    m_defenseAuto.firstCountry = nullptr;
+    m_defenseAuto.secondCountry= nullptr;
   }
 }
 
@@ -2619,9 +2648,20 @@ void GameAutomaton::actionNextPlayer()
   if ( currentPlayer()->isVirtual()
     || currentPlayer()->isAI()
     || m_currentPlayerPlayed
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    || (KMessageBox::questionTwoActions (m_game,
+#else
     || (KMessageBox::questionYesNo (m_game,
-                                     i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn?",m_currentPlayer),
-                                     i18n("Really Next Player?")) == KMessageBox::Yes) )
+#endif
+                                    i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn?",m_currentPlayer),
+                                    i18n("Really Next Player?"),
+                                    KGuiItem(i18nc("@action:button", "Next Player")),
+                                    KStandardGuiItem::cancel())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+       == KMessageBox::PrimaryAction) )
+#else
+       == KMessageBox::Yes) )
+#endif
   {
     QByteArray buffer;
     QDataStream stream(&buffer, QIODevice::WriteOnly);
@@ -2676,7 +2716,7 @@ void GameAutomaton::checkGoal(Player* player)
 {
   QByteArray buffer;
   QDataStream stream(&buffer, QIODevice::WriteOnly);
-  if (player == 0)
+  if (player == nullptr)
     stream << currentPlayer()->id();
   else
     stream << player->id();
